RealFloatVector

Trait RealFloatVector 

pub trait RealFloatVector:
    RealValue
    + FloatVector<Element: RealValue>
    + CastVector<Self>
    + RealMathWithPolicy
    + SwizzleVector { }
A real FloatVector usable as the inner storage of a Complex vector.

The complex primitives (sqrt, abs, signum, rcp, …) are built out of the inner vector’s hypot/reciprocal, so the policy math library is required here. Dual/Compensated split theirs into a separate tier; there is no useful math-free tier to split out of this one.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors