#[repr(C)]pub struct Complex<V> {
pub re: V,
pub im: V,
}Expand description
A complex number re + im*i.
The derived PartialOrd is lexicographic on (re, im), matching
PartialOrdVector. The crate docs
cover the rest of the ordering/sign/rounding semantics.
Fields
re: VThe real part.
im: VThe imaginary part.
Implementations
Sourceimpl<V: RealFloatVector> Complex<V>
impl<V: RealFloatVector> Complex<V>
Sourcepub fn splat_parts(re: V::Element, im: V::Element) -> Self
pub fn splat_parts(re: V::Element, im: V::Element) -> Self
Splat a real and imaginary part across every lane.
Sourceimpl<V: RealValue> Complex<V>
impl<V: RealValue> Complex<V>
Sourcepub const fn new(re: V, im: V) -> Self
pub const fn new(re: V, im: V) -> Self
Creates a complex number with the given real and imaginary parts.
Sourcepub const fn real(re: V) -> Self
pub const fn real(re: V) -> Self
Creates a complex number with the given real part and zero imaginary part.
Sourcepub const fn imag(im: V) -> Self
pub const fn imag(im: V) -> Self
Creates a complex number with zero real part and the given imaginary part.